@@ -13,9 +13,9 @@ rel_path_encoder = "/encoder_VAE"
 abs_path_VAE = os.path.join(script_dir, rel_path_encoder)
 ENCODER_LOCATION = os.path.join(script_dir, rel_path_encoder)
 
-class Timestamp2Vec(Model):
+class Timestamp2Vec_model(Model):
     def __init__(self):
-        super(Timestamp2Vec, self).__init__()
+        super(Timestamp2Vec_model, self).__init__()
         self.vectorize = Vectorize()
         self.encoder = keras.models.load_model(ENCODER_LOCATION)
     
